@@ -1,38 +1,31 @@
 
-
-
 require "sqlite3"
 
 
-db = sqlite3.open_memory()
-
-db:exec([[ 
+local db = sqlite3.open_memory()
 
+db:exec[[
   CREATE TABLE test (
-    id		INTEGER PRIMARY KEY,
-    content	VARCHAR
+    id        INTEGER PRIMARY KEY,
+    content   VARCHAR
   );
-  
-]])
+]]
 
+local insert_stmt = assert( db:prepare("INSERT INTO test VALUES (NULL, ?)") )
 
-insert_stmt = assert( db:prepare("INSERT INTO test VALUES (NULL, ?)") )
-
-function insert(data)
+local function insert(data)
   insert_stmt:bind(data)
   insert_stmt:exec()
 end
 
+local select_stmt = assert( db:prepare("SELECT * FROM test") )
 
-select_stmt = assert( db:prepare("SELECT * FROM test") )
-
-function select()
+local function select()
   for row in select_stmt:rows() do
     print(row.id, row.content)
   end
 end
 
-
 insert("Hello World")
 print("First:")
 select()
@@ -44,5 +37,3 @@ select()
 insert("Hello Sqlite3")
 print("Third:")
 select()
-
-
